CurrentOpeningHours class
Constructors
-
CurrentOpeningHours({bool? openNow, List<
CurrentOpeningHoursPeriod> ? periods, List<String> ? weekdayText}) -
CurrentOpeningHours.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- openNow → bool?
-
final
-
periods
→ List<
CurrentOpeningHoursPeriod> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
weekdayText
→ List<
String> ? -
final
Methods
-
copyWith(
{bool? openNow, List< CurrentOpeningHoursPeriod> ? periods, List<String> ? weekdayText}) → CurrentOpeningHours -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited