CurrentOpeningHoursPeriod class

Constructors

CurrentOpeningHoursPeriod({PurpleClose? close, PurpleClose? open})
CurrentOpeningHoursPeriod.fromJson(Map<String, dynamic> json)
factory

Properties

close PurpleClose?
final
hashCode int
The hash code for this object.
no setterinherited
open PurpleClose?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PurpleClose? close, PurpleClose? open}) CurrentOpeningHoursPeriod
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited