menu
google_map_service package
documentation
data/models/google_map/place_detail_response.dart
Geometry class
Geometry class
dark_mode
light_mode
Geometry
class
Constructors
Geometry
({
Location
?
location
,
Viewport
?
viewport
})
Geometry.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
location
→
Location
?
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
viewport
→
Viewport
?
final
Methods
copyWith
(
{
Location
?
location
,
Viewport
?
viewport
})
→
Geometry
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
google_map_service package
documentation
data/models/google_map/place_detail_response
Geometry class
place_detail_response library