Location class
- Available extensions
Constructors
Properties
Methods
-
copyWith(
{double? lat, double? lng}) → Location -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCoordinates(
{bool reverse = false}) → List< double> -
Available on Location, provided by the LocationExt extension
Converts the current Location object into a list of coordinates[lat, lng]. -
toJson(
) → Map< String, dynamic> -
toLatLng(
{bool reverse = false}) → LatLng -
Available on Location, provided by the LocationExt extension
Converts the current Location object into aLatLnginstance. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited