PlaceDetailResponse class

Constructors

PlaceDetailResponse({List? htmlAttributions, PlaceDetails? result, String? status})
PlaceDetailResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
htmlAttributions List?
final
result PlaceDetails?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

copyWith({List? htmlAttributions, PlaceDetails? result, String? status}) PlaceDetailResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited