PlaceDetails class

Constructors

PlaceDetails({List<AddressComponent>? addressComponents, String? adrAddress, String? businessStatus, CurrentOpeningHours? currentOpeningHours, EditorialSummary? editorialSummary, String? formattedAddress, Geometry? geometry, String? icon, String? iconBackgroundColor, String? iconMaskBaseUri, String? name, OpeningHours? openingHours, List<Photo>? photos, String? placeId, PlusCode? plusCode, double? rating, String? reference, List<Review>? reviews, List<String>? types, String? url, int? userRatingsTotal, int? utcOffset, String? vicinity, String? website, bool? wheelchairAccessibleEntrance})
PlaceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

addressComponents List<AddressComponent>?
final
adrAddress String?
final
businessStatus String?
final
currentOpeningHours CurrentOpeningHours?
final
editorialSummary EditorialSummary?
final
formattedAddress String?
final
geometry Geometry?
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
iconBackgroundColor String?
final
iconMaskBaseUri String?
final
name String?
final
openingHours OpeningHours?
final
photos List<Photo>?
final
placeId String?
final
plusCode PlusCode?
final
rating double?
final
reference String?
final
reviews List<Review>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types List<String>?
final
url String?
final
userRatingsTotal int?
final
utcOffset int?
final
vicinity String?
final
website String?
final
wheelchairAccessibleEntrance bool?
final

Methods

copyWith({List<AddressComponent>? addressComponents, String? adrAddress, String? businessStatus, CurrentOpeningHours? currentOpeningHours, EditorialSummary? editorialSummary, String? formattedAddress, Geometry? geometry, String? icon, String? iconBackgroundColor, String? iconMaskBaseUri, String? name, OpeningHours? openingHours, List<Photo>? photos, String? placeId, PlusCode? plusCode, double? rating, String? reference, List<Review>? reviews, List<String>? types, String? url, int? userRatingsTotal, int? utcOffset, String? vicinity, String? website, bool? wheelchairAccessibleEntrance}) PlaceDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited