PurpleClose class

Constructors

PurpleClose({DateTime? date, int? day, String? time})
PurpleClose.fromJson(Map<String, dynamic> json)
factory

Properties

date DateTime?
final
day int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
final

Methods

copyWith({DateTime? date, int? day, String? time}) PurpleClose
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited