Review class

Constructors

Review({String? authorName, String? authorUrl, String? language, String? originalLanguage, String? profilePhotoUrl, int? rating, String? relativeTimeDescription, String? text, int? time, bool? translated})
Review.fromJson(Map<String, dynamic> json)
factory

Properties

authorName String?
final
authorUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
language String?
final
originalLanguage String?
final
profilePhotoUrl String?
final
rating int?
final
relativeTimeDescription String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
time int?
final
translated bool?
final

Methods

copyWith({String? authorName, String? authorUrl, String? language, String? originalLanguage, String? profilePhotoUrl, int? rating, String? relativeTimeDescription, String? text, int? time, bool? translated}) Review
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited