menu
google_map_service package
documentation
data/models/google_map/place_detail_response.dart
Viewport class
Viewport class
dark_mode
light_mode
Viewport
class
Constructors
Viewport
({
Location
?
northeast
,
Location
?
southwest
})
Viewport.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
northeast
→
Location
?
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
southwest
→
Location
?
final
Methods
copyWith
(
{
Location
?
northeast
,
Location
?
southwest
})
→
Viewport
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
google_map_service package
documentation
data/models/google_map/place_detail_response
Viewport class
place_detail_response library