Prediction class

Constructors

Prediction({required String? description, required List<MatchedSubstring> matchedSubstrings, required String? placeId, required String? reference, required StructuredFormatting? structuredFormatting, required List<Term> terms, required List<String> types})
Prediction.fromJson(Map<String, dynamic> json)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
matchedSubstrings List<MatchedSubstring>
final
placeId String?
final
reference String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredFormatting StructuredFormatting?
final
terms List<Term>
final
types List<String>
final

Methods

copyWith({String? description, List<MatchedSubstring>? matchedSubstrings, String? placeId, String? reference, StructuredFormatting? structuredFormatting, List<Term>? terms, List<String>? types}) Prediction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited