GeocodingResults class

Constructors

GeocodingResults({required Destination? origin, required Destination? destination})
GeocodingResults.fromJson(Map<String, dynamic> json)
factory

Properties

destination Destination?
final
hashCode int
The hash code for this object.
no setterinherited
origin Destination?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Destination? origin, Destination? destination}) GeocodingResults
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited