menu
google_map_service package
documentation
data/models/google_map/routes_response.dart
High class
High class
dark_mode
light_mode
High
class
Constructors
High
({
required
double
?
latitude
,
required
double
?
longitude
})
High.fromJson
(
Map
<
String
,
dynamic
>
json
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
latitude
→
double
?
final
longitude
→
double
?
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
copyWith
(
{
double
?
latitude
,
double
?
longitude
})
→
High
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
google_map_service package
documentation
data/models/google_map/routes_response
High class
routes_response library