LegLocalizedValues class

Constructors

LegLocalizedValues({required Distance? distance, required Distance? duration, required Distance? staticDuration})
LegLocalizedValues.fromJson(Map<String, dynamic> json)
factory

Properties

distance Distance?
final
duration Distance?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staticDuration Distance?
final

Methods

copyWith({Distance? distance, Distance? duration, Distance? staticDuration}) LegLocalizedValues
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited