Step class

Constructors

Step({required int? distanceMeters, required String? staticDuration, required Polyline? polyline, required Location? startLocation, required Location? endLocation, required NavigationInstruction? navigationInstruction, required StepLocalizedValues? localizedValues, required String? travelMode})
Step.fromJson(Map<String, dynamic> json)
factory

Properties

distanceMeters int?
final
endLocation Location?
final
hashCode int
The hash code for this object.
no setterinherited
localizedValues StepLocalizedValues?
final
final
polyline Polyline?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLocation Location?
final
staticDuration String?
final
travelMode String?
final

Methods

copyWith({int? distanceMeters, String? staticDuration, Polyline? polyline, Location? startLocation, Location? endLocation, NavigationInstruction? navigationInstruction, StepLocalizedValues? localizedValues, String? travelMode}) Step
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited