Viewport class

Constructors

Viewport({required High? low, required High? high})
Viewport.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
high High?
final
low High?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({High? low, High? high}) Viewport
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited