Photo class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
final
-
htmlAttributions
→ List<
String> ? -
final
- photoReference → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
final
Methods
-
copyWith(
{int? height, List< String> ? htmlAttributions, String? photoReference, int? width}) → Photo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited