Destination class

Constructors

Destination({required PolylineDetails? geocoderStatus, required List<String> type, required String? placeId, required bool? partialMatch})
Destination.fromJson(Map<String, dynamic> json)
factory

Properties

geocoderStatus PolylineDetails?
final
hashCode int
The hash code for this object.
no setterinherited
partialMatch bool?
final
placeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type List<String>
final

Methods

copyWith({PolylineDetails? geocoderStatus, List<String>? type, String? placeId, bool? partialMatch}) Destination
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited