Leg class

Constructors

Leg({required int? distanceMeters, required String? duration, required String? staticDuration, required Polyline? polyline, required Location? startLocation, required Location? endLocation, required List<Step> steps, required LegLocalizedValues? localizedValues})
Leg.fromJson(Map<String, dynamic> json)
factory

Properties

distanceMeters int?
final
duration String?
final
endLocation Location?
final
hashCode int
The hash code for this object.
no setterinherited
localizedValues LegLocalizedValues?
final
polyline Polyline?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLocation Location?
final
staticDuration String?
final
steps List<Step>
final

Methods

copyWith({int? distanceMeters, String? duration, String? staticDuration, Polyline? polyline, Location? startLocation, Location? endLocation, List<Step>? steps, LegLocalizedValues? localizedValues}) Leg
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited